#include <Servo.h>
#include <Wire.h>
#include <LiquidCrystal_I2C.h>

#include <Arduino.h>
#include "HX711.h"

// HX711 circuit wiring
const int LOADCELL_DOUT_PIN = 4;
const int LOADCELL_SCK_PIN = 5;
#include <Wire.h> 


LiquidCrystal_I2C lcd(0x27,16,2); 

HX711 scale;

// Configurare RemoteXY
#define REMOTEXY_MODE__SOFTSERIAL
#include <SoftwareSerial.h>
#include <RemoteXY.h>

// Setările de conexiune RemoteXY
#define REMOTEXY_SERIAL_RX 2
#define REMOTEXY_SERIAL_TX 3
#define REMOTEXY_SERIAL_SPEED 9600
int oldangle=0;
uint8_t RemoteXY_CONF[] = // 27 bytes
  { 255,1,0,0,0,20,0,17,0,0,0,31,1,106,200,1,1,1,0,4,
  27,69,59,12,128,2,26 };

struct {
  int8_t slider_01; // de la 0 la 100
  uint8_t connect_flag;  // =1 dacă este conectat, altfel =0
} RemoteXY;


Servo servo;

void setup() {
    
  RemoteXY_Init(); // Inițializare RemoteXY
  Serial.begin(9600);
  delay(500);
  servo.attach(9);  // Atașăm servomotorul la pinul digital 9
  lcd.init();
  lcd.backlight();

  Serial.begin(57600);
  Serial.println("HX711 Demo");
  Serial.println("Initializing the scale");

  scale.begin(LOADCELL_DOUT_PIN, LOADCELL_SCK_PIN);

  Serial.println("Before setting up the scale:");
  Serial.print("read: \t\t");
  Serial.println(scale.read());      // print a raw reading from the ADC

  Serial.print("read average: \t\t");
  Serial.println(scale.read_average(20));   // print the average of 20 readings from the ADC

  Serial.print("get value: \t\t");
  Serial.println(scale.get_value(5));   // print the average of 5 readings from the ADC minus the tare weight (not set yet)

  Serial.print("get units: \t\t");
  Serial.println(scale.get_units(5), 1);  // print the average of 5 readings from the ADC minus tare weight (not set) divided
            // by the SCALE parameter (not set yet)
            
  scale.set_scale(210);
  //scale.set_scale(-471.497);                      // this value is obtained by calibrating the scale with known weights; see the README for details
  scale.tare();               // reset the scale to 0

  Serial.println("After setting up the scale:");

  Serial.print("read: \t\t");
  Serial.println(scale.read());                 // print a raw reading from the ADC

  Serial.print("read average: \t\t");
  Serial.println(scale.read_average(20));       // print the average of 20 readings from the ADC

  Serial.print("get value: \t\t");
  Serial.println(scale.get_value(5));   // print the average of 5 readings from the ADC minus the tare weight, set with tare()

  Serial.print("get units: \t\t");
  Serial.println(scale.get_units(5), 1);        // print the average of 5 readings from the ADC minus tare weight, divided
            // by the SCALE parameter set with set_scale

  Serial.println("Readings:");
}

void loop() {
  RemoteXY_Handler(); // Gestionare RemoteXY
  
  Serial.print("one reading:\t");
  Serial.print(scale.get_units(), 1);
  Serial.print("\t| average:\t");
  Serial.println(scale.get_units(10), 5);

  int angle = map(RemoteXY.slider_01, 0, 100, 90, 45); // Mapează valoarea sliderului la unghiuri între 0 și 90 de grade
  if (oldangle!=angle)
  {
  servo.write(angle); // Rotim servomotorul la unghiul specificat
  oldangle=angle;
  }

  lcd.clear();
  lcd.setCursor(0, 0);
  lcd.print("Unghi: ");
  lcd.print(angle);
  lcd.setCursor(0, 1);  
  lcd.print(scale.get_units(), 1);
  lcd.print(" g");

  // Întârziere scurtă pentru a evita problemele de interfață
  delay(100);
}
